@@ -39,6 +39,6 @@ class MysqlPool(BaseConnectionPool):
     def sync_create_pool(self):
         pool = PooledDB(creator=pymysql, host=self.conn_info.host, port=self.conn_info.port, user=self.conn_info.user,
                         passwd=self.conn_info.password, db=self.conn_info.db_name,
-                        mincached=self.conn_info.min_size, blocking=False,
+                        mincached=self.conn_info.min_size, blocking=False, maxusage=self.conn_info.min_size,
                         ping=1, maxconnections=self.conn_info.max_size, charset="utf8mb4", autocommit=True)
         return pool
