@@ -3,6 +3,9 @@ import aiohttp
 import tornado.options
 import requests
 import py_eureka_client.eureka_client as eureka_client
+from lesscode.web.status_code import StatusCode
+
+from lesscode.web.business_exception import BusinessException
 
 
 async def post(path, data=None,
@@ -20,8 +23,12 @@ async def post(path, data=None,
             async with session.post(base_url + path, json=data, **kwargs) as resp:
                 if result_type == "json":
                     result = await resp.json()
-                    if result.get("status") == "00000" and not pack:
-                        result = result.get("data")
+                    if not pack:
+                        if result.get("status") == "00000":
+                            result = result.get("data")
+                        else:
+                            message = f'ori_message:{result.get("status", "")}, {result.get("message", "未知错误")}'
+                            raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
                 elif result_type == "text":
                     result = await resp.text()
                 else:
@@ -31,8 +38,12 @@ async def post(path, data=None,
             async with session.post(base_url + path, data=data, **kwargs) as resp:
                 if result_type == "json":
                     result = await resp.json()
-                    if result.get("status") == "00000" and not pack:
-                        result = result.get("data")
+                    if not pack:
+                        if result.get("status") == "00000":
+                            result = result.get("data")
+                        else:
+                            message = f'ori_message:{result.get("status", "")}, {result.get("message", "未知错误")}'
+                            raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
                 elif result_type == "text":
                     result = await resp.text()
                 else:
@@ -46,8 +57,12 @@ async def get(path, params=None, base_url=tornado.options.options.data_server, r
         async with session.get(base_url + path, params=params, **kwargs) as resp:
             if result_type == "json":
                 result = await resp.json()
-                if result.get("status") == "00000" and not pack:
-                    result = result.get("data")
+                if not pack:
+                    if result.get("status") == "00000":
+                        result = result.get("data")
+                    else:
+                        message = f'ori_message:{result.get("status", "")}, {result.get("message", "未知错误")}'
+                        raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
             elif result_type == "text":
                 result = await resp.text()
             else:
@@ -59,8 +74,12 @@ def sync_get(path, params=None, base_url=tornado.options.options.data_server, re
     res = requests.get(base_url + path, params=params, **kwargs)
     if result_type == "json":
         res = res.json()
-        if res.get("status") == "00000" and not pack:
-            res = res.get("data")
+        if not pack:
+            if res.get("status") == "00000":
+                res = res.get("data")
+            else:
+                message = f'ori_message:{res.get("status", "")}, {res.get("message", "未知错误")}'
+                raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
     elif result_type == "text":
         res = res.text
     else:
@@ -82,8 +101,12 @@ def sync_post(path, data=None,
         res = requests.post(base_url + path, data=data, **kwargs)
     if result_type == "json":
         res = res.json()
-        if res.get("status") == "00000" and not pack:
-            res = res.get("data")
+        if not pack:
+            if res.get("status") == "00000":
+                res = res.get("data")
+            else:
+                message = f'ori_message:{res.get("status", "")}, {res.get("message", "未知错误")}'
+                raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
     elif result_type == "text":
         res = res.text
     else:
@@ -101,8 +124,12 @@ def eureka_request(path="", return_type="json", method="GET", data=None, app_nam
     res = eureka_client.do_service(app_name=app_name, service=path, return_type=return_type, method=method, data=data,
                                    **kwargs)
     if return_type == "json" and not pack:
-        if res.get("status") == "00000" and not pack:
-            res = res.get("data")
+        if not pack:
+            if res.get("status") == "00000":
+                res = res.get("data")
+            else:
+                message = f'ori_message:{res.get("status", "")}, {res.get("message", "未知错误")}'
+                raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
     return res
 
 
